==> blatann-0.3.2-py3-none-any.whl: blatann/waitables/event_waitable.py <==
from typing import Generic, Tuple, Callable
from blatann.waitables.waitable import Waitable
from blatann.event_type import Event, TSender, TEvent


class EventWaitable(Waitable, Generic[TSender, TEvent]):
    """
    Waitable implementation which waits on an :class:`~blatann.event_type.Event`.
    """
    def __init__(self, event: Event[TSender, TEvent]):
        super(EventWaitable, self).__init__(n_args=2)
        self._event = event
        self._event.register(self._on_event)

    def _on_event(self, *args):
        self._event.deregister(self._on_event)
        self._notify(*args)

    def _on_timeout(self):
        self._event.deregister(self._on_event)

    def wait(self, timeout=None, exception_on_timeout=True) -> Tuple[TSender, TEvent]:
        res = super(EventWaitable, self).wait(timeout, exception_on_timeout)
        if res is None:  # Timeout, send None, None for the sender and event_args
            return None, None
        return res

    def then(self, callback: Callable[[TSender, TEvent], None]):
        super(EventWaitable, self).then(callback)


class IdBasedEventWaitable(EventWaitable):
    """
    Extension of :class:`EventWaitable` for high-churn events which require IDs,
    such as characteristic read, write and notify operations
    """
    def __init__(self, event, event_id):
        super(IdBasedEventWaitable, self).__init__(event)
        self.id = event_id

    def _on_event(self, sender, event_args):
        if event_args.id == self.id:
            super(IdBasedEventWaitable, self)._on_event(sender, event_args)

==> blatann-0.3.3-py3-none-any.whl: blatann/waitables/event_waitable.py <==
from typing import Generic, Tuple, Callable
from blatann.waitables.waitable import Waitable
from blatann.event_type import Event, TSender, TEvent


class EventWaitable(Waitable, Generic[TSender, TEvent]):
    """
    Waitable implementation which waits on an :class:`~blatann.event_type.Event`.
    """
    def __init__(self, event: Event[TSender, TEvent]):
        super(EventWaitable, self).__init__(n_args=2)
        self._event = event
        self._event.register(self._on_event)

    def _on_event(self, *args):
        self._event.deregister(self._on_event)
        self._notify(*args)

    def _on_timeout(self):
        self._event.deregister(self._on_event)

    def wait(self, timeout=None, exception_on_timeout=True) -> Tuple[TSender, TEvent]:
        res = super(EventWaitable, self).wait(timeout, exception_on_timeout)
        if res is None:  # Timeout, send None, None for the sender and event_args
            return None, None
        return res

    def then(self, callback: Callable[[TSender, TEvent], None]):
        return super(EventWaitable, self).then(callback)


class IdBasedEventWaitable(EventWaitable):
    """
    Extension of :class:`EventWaitable` for high-churn events which require IDs,
    such as characteristic read, write and notify operations
    """
    def __init__(self, event, event_id):
        super(IdBasedEventWaitable, self).__init__(event)
        self.id = event_id

    def _on_event(self, sender, event_args):
        if event_args.id == self.id:
            super(IdBasedEventWaitable, self)._on_event(sender, event_args)
